@@ -55,6 +55,7 @@ static bool ShowHelp(CommandLine &)					/*{{{*/
 									/*}}}*/
 static std::vector<aptDispatchWithHelp> GetCommands()			/*{{{*/
 {
+   // advanced commands are left undocumented on purpose
    return {
       // query
       {"list", &DoList, _("list packages based on package names")},
@@ -78,6 +79,7 @@ static std::vector<aptDispatchWithHelp> GetCommands()			/*{{{*/
       // misc
       {"edit-sources", &EditSources, _("edit the source information file")},
       {"moo", &DoMoo, nullptr},
+      {"satisfy", &DoBuildDep, _("satisfy dependency strings")},
 
       // for compat with muscle memory
       {"dist-upgrade", &DoDistUpgrade, nullptr},
